# eric7.HelpViewer.OpenPagesWidget

Module implementing a widget showing the list of open pages.

### Global Attributes

None

### Classes

OpenPagesWidget | Class implementing a widget showing the list of open pages.

### Functions

None

## OpenPagesWidget

Class implementing a widget showing the list of open pages.

### Signals

currentPageChanged(index)
  emitted to signal a change of the current page index

### Derived from

QListWidget

### Class Attributes

None

### Class Methods

None

### Methods

OpenPagesWidget | Constructor
__contextMenuClose | Private slot to close a page via the context menu.
__contextMenuCloseAll | Private slot to close all pages via the context menu.
__contextMenuCloseOthers | Private slot to close all other pages via the context menu.
__contextMenuCopyUrlToClipboard | Private slot to copy the URL to the clipboard.
__currentPageChanged | Private slot to handle a change of the shown page.
__currentRowChanged | Private slot handling a change of the current row.
__initContextMenu | Private method to initialize the context menu.
__removeViewer | Private method to remove a viewer page.
__showContextMenu | Private slot to handle the customContextMenuRequested signal of the viewlist.
__viewerTitleChanged | Private method to handle the change of a viewer title.
addPage | Public method to add a viewer page to our list.
closeAllPages | Public slot to close all pages.
closeCurrentPage | Public slot to close the current page.
closeOtherPages | Public slot to close all other pages.
insertPage | Public method to insert a viewer page into our list.

### Static Methods

None

#### OpenPagesWidget (Constructor)

OpenPagesWidget(stack, parent=None)

Constructor

stack (QStackedWidget)
  reference to the stack widget containing the open help pages
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### OpenPagesWidget.__contextMenuClose

__contextMenuClose()

Private slot to close a page via the context menu.

#### OpenPagesWidget.__contextMenuCloseAll

__contextMenuCloseAll()

Private slot to close all pages via the context menu.

#### OpenPagesWidget.__contextMenuCloseOthers

__contextMenuCloseOthers()

Private slot to close all other pages via the context menu.

#### OpenPagesWidget.__contextMenuCopyUrlToClipboard

__contextMenuCopyUrlToClipboard()

Private slot to copy the URL to the clipboard.

#### OpenPagesWidget.__currentPageChanged

__currentPageChanged(index)

Private slot to handle a change of the shown page.

index (int)
  index of the current page

#### OpenPagesWidget.__currentRowChanged

__currentRowChanged(row)

Private slot handling a change of the current row.

row (int)
  current row

#### OpenPagesWidget.__initContextMenu

__initContextMenu()

Private method to initialize the context menu.

#### OpenPagesWidget.__removeViewer

__removeViewer(row)

Private method to remove a viewer page.

row (int)
  row associated with the viewer

#### OpenPagesWidget.__showContextMenu

__showContextMenu(point)

Private slot to handle the customContextMenuRequested signal of the viewlist.

point (QPoint)
  position to open the menu at

#### OpenPagesWidget.__viewerTitleChanged

__viewerTitleChanged(viewer)

Private method to handle the change of a viewer title.

viewer (HelpViewerImpl)
  reference to the viewer that change title

#### OpenPagesWidget.addPage

addPage(viewer, background=False)

Public method to add a viewer page to our list.

viewer (HelpViewerImpl)
  reference to the viewer object
background (bool (optional))
  flag indicating to not change the current page (defaults to False)

#### OpenPagesWidget.closeAllPages

closeAllPages()

Public slot to close all pages.

#### OpenPagesWidget.closeCurrentPage

closeCurrentPage()

Public slot to close the current page.

#### OpenPagesWidget.closeOtherPages

closeOtherPages()

Public slot to close all other pages.

#### OpenPagesWidget.insertPage

insertPage(index, viewer, background=False)

Public method to insert a viewer page into our list.

index (int)
  index to insert at
viewer (HelpViewerImpl)
  reference to the viewer object
background (bool (optional))
  flag indicating to not change the current page (defaults to False)

Up